// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef SERVICE_ANYTHING_GLOBAL_H
#define SERVICE_ANYTHING_GLOBAL_H

#include <dfm-base/dfm_log_defines.h>

#define SERVICEANYTHING_NAMESPACE service_anything
#define SERVICEANYTHING_BEGIN_NAMESPACE namespace SERVICEANYTHING_NAMESPACE {
#define SERVICEANYTHING_END_NAMESPACE }
#define SERVICEANYTHING_USE_NAMESPACE using namespace SERVICEANYTHING_NAMESPACE;

SERVICEANYTHING_BEGIN_NAMESPACE
DFM_LOG_USE_CATEGORY(SERVICEANYTHING_NAMESPACE)
SERVICEANYTHING_END_NAMESPACE

#endif   // SERVICE_ANYTHING_GLOBAL_H
