/****************************************************************************
** Meta object code from reading C++ file 'workspacewidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-workspace/views/workspacewidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspacewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget_t {
    QByteArrayData data[25];
    char stringdata0[395];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget_t qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget = {
    {
QT_MOC_LITERAL(0, 0, 36), // "dfmplugin_workspace::Workspac..."
QT_MOC_LITERAL(1, 37, 17), // "onOpenUrlInNewTab"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 8), // "windowId"
QT_MOC_LITERAL(4, 65, 3), // "url"
QT_MOC_LITERAL(5, 69, 19), // "onCurrentTabChanged"
QT_MOC_LITERAL(6, 89, 8), // "tabIndex"
QT_MOC_LITERAL(7, 98, 17), // "onRequestCloseTab"
QT_MOC_LITERAL(8, 116, 5), // "index"
QT_MOC_LITERAL(9, 122, 11), // "remainState"
QT_MOC_LITERAL(10, 134, 19), // "onTabAddableChanged"
QT_MOC_LITERAL(11, 154, 7), // "addable"
QT_MOC_LITERAL(12, 162, 16), // "showNewTabButton"
QT_MOC_LITERAL(13, 179, 16), // "hideNewTabButton"
QT_MOC_LITERAL(14, 196, 21), // "onNewTabButtonClicked"
QT_MOC_LITERAL(15, 218, 9), // "onNextTab"
QT_MOC_LITERAL(16, 228, 13), // "onPreviousTab"
QT_MOC_LITERAL(17, 242, 17), // "onCloseCurrentTab"
QT_MOC_LITERAL(18, 260, 14), // "onCreateNewTab"
QT_MOC_LITERAL(19, 275, 17), // "onCreateNewWindow"
QT_MOC_LITERAL(20, 293, 20), // "onSetCurrentTabIndex"
QT_MOC_LITERAL(21, 314, 20), // "onRefreshCurrentView"
QT_MOC_LITERAL(22, 335, 22), // "handleViewStateChanged"
QT_MOC_LITERAL(23, 358, 17), // "initUiForSizeMode"
QT_MOC_LITERAL(24, 376, 18) // "onAnimDelayTimeout"

    },
    "dfmplugin_workspace::WorkspaceWidget\0"
    "onOpenUrlInNewTab\0\0windowId\0url\0"
    "onCurrentTabChanged\0tabIndex\0"
    "onRequestCloseTab\0index\0remainState\0"
    "onTabAddableChanged\0addable\0"
    "showNewTabButton\0hideNewTabButton\0"
    "onNewTabButtonClicked\0onNextTab\0"
    "onPreviousTab\0onCloseCurrentTab\0"
    "onCreateNewTab\0onCreateNewWindow\0"
    "onSetCurrentTabIndex\0onRefreshCurrentView\0"
    "handleViewStateChanged\0initUiForSizeMode\0"
    "onAnimDelayTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_workspace__WorkspaceWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   99,    2, 0x0a /* Public */,
       5,    1,  104,    2, 0x0a /* Public */,
       7,    2,  107,    2, 0x0a /* Public */,
      10,    1,  112,    2, 0x0a /* Public */,
      12,    0,  115,    2, 0x0a /* Public */,
      13,    0,  116,    2, 0x0a /* Public */,
      14,    0,  117,    2, 0x0a /* Public */,
      15,    0,  118,    2, 0x0a /* Public */,
      16,    0,  119,    2, 0x0a /* Public */,
      17,    0,  120,    2, 0x0a /* Public */,
      18,    0,  121,    2, 0x0a /* Public */,
      19,    0,  122,    2, 0x0a /* Public */,
      20,    1,  123,    2, 0x0a /* Public */,
      21,    0,  126,    2, 0x0a /* Public */,
      22,    0,  127,    2, 0x0a /* Public */,
      23,    0,  128,    2, 0x0a /* Public */,
      24,    0,  129,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QUrl,    3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dfmplugin_workspace::WorkspaceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WorkspaceWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->onOpenUrlInNewTab((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 1: _t->onCurrentTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->onRequestCloseTab((*reinterpret_cast< const int(*)>(_a[1])),(*reinterpret_cast< const bool(*)>(_a[2]))); break;
        case 3: _t->onTabAddableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->showNewTabButton(); break;
        case 5: _t->hideNewTabButton(); break;
        case 6: _t->onNewTabButtonClicked(); break;
        case 7: _t->onNextTab(); break;
        case 8: _t->onPreviousTab(); break;
        case 9: _t->onCloseCurrentTab(); break;
        case 10: _t->onCreateNewTab(); break;
        case 11: _t->onCreateNewWindow(); break;
        case 12: _t->onSetCurrentTabIndex((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 13: _t->onRefreshCurrentView(); break;
        case 14: _t->handleViewStateChanged(); break;
        case 15: _t->initUiForSizeMode(); break;
        case 16: _t->onAnimDelayTimeout(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_workspace::WorkspaceWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<dfmbase::AbstractFrame::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget.data,
    qt_meta_data_dfmplugin_workspace__WorkspaceWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_workspace::WorkspaceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::WorkspaceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_workspace__WorkspaceWidget.stringdata0))
        return static_cast<void*>(this);
    return dfmbase::AbstractFrame::qt_metacast(_clname);
}

int dfmplugin_workspace::WorkspaceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dfmbase::AbstractFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
