/****************************************************************************
** Meta object code from reading C++ file 'vaultactivesavekeyfileview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-vault/views/createvaultview/vaultactivesavekeyfileview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultactivesavekeyfileview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_vault__RadioFrame_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_vault__RadioFrame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_vault__RadioFrame_t qt_meta_stringdata_dfmplugin_vault__RadioFrame = {
    {
QT_MOC_LITERAL(0, 0, 27) // "dfmplugin_vault::RadioFrame"

    },
    "dfmplugin_vault::RadioFrame"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_vault__RadioFrame[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dfmplugin_vault::RadioFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_vault::RadioFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_vault__RadioFrame.data,
    qt_meta_data_dfmplugin_vault__RadioFrame,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_vault::RadioFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::RadioFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_vault__RadioFrame.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dfmplugin_vault::RadioFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView_t {
    QByteArrayData data[11];
    char stringdata0[167];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView_t qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView = {
    {
QT_MOC_LITERAL(0, 0, 43), // "dfmplugin_vault::VaultActiveS..."
QT_MOC_LITERAL(1, 44, 11), // "sigAccepted"
QT_MOC_LITERAL(2, 56, 0), // ""
QT_MOC_LITERAL(3, 57, 18), // "slotNextBtnClicked"
QT_MOC_LITERAL(4, 76, 18), // "slotSelectRadioBtn"
QT_MOC_LITERAL(5, 95, 16), // "QAbstractButton*"
QT_MOC_LITERAL(6, 112, 3), // "btn"
QT_MOC_LITERAL(7, 116, 14), // "slotChangeEdit"
QT_MOC_LITERAL(8, 131, 8), // "fileName"
QT_MOC_LITERAL(9, 140, 21), // "slotSelectCurrentFile"
QT_MOC_LITERAL(10, 162, 4) // "file"

    },
    "dfmplugin_vault::VaultActiveSaveKeyFileView\0"
    "sigAccepted\0\0slotNextBtnClicked\0"
    "slotSelectRadioBtn\0QAbstractButton*\0"
    "btn\0slotChangeEdit\0fileName\0"
    "slotSelectCurrentFile\0file"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_vault__VaultActiveSaveKeyFileView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   40,    2, 0x0a /* Public */,
       4,    1,   41,    2, 0x0a /* Public */,
       7,    1,   44,    2, 0x0a /* Public */,
       9,    1,   47,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void, QMetaType::QString,   10,

       0        // eod
};

void dfmplugin_vault::VaultActiveSaveKeyFileView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VaultActiveSaveKeyFileView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sigAccepted(); break;
        case 1: _t->slotNextBtnClicked(); break;
        case 2: _t->slotSelectRadioBtn((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 3: _t->slotChangeEdit((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->slotSelectCurrentFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractButton* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (VaultActiveSaveKeyFileView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VaultActiveSaveKeyFileView::sigAccepted)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_vault::VaultActiveSaveKeyFileView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView.data,
    qt_meta_data_dfmplugin_vault__VaultActiveSaveKeyFileView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_vault::VaultActiveSaveKeyFileView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::VaultActiveSaveKeyFileView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_vault__VaultActiveSaveKeyFileView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dfmplugin_vault::VaultActiveSaveKeyFileView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_vault::VaultActiveSaveKeyFileView::sigAccepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
