// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "tab_p.h"

using namespace dfmplugin_workspace;

TabPrivate::TabPrivate()
{
}
