/****************************************************************************
** Meta object code from reading C++ file 'titlebareventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-titlebar/events/titlebareventreceiver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'titlebareventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver_t {
    QByteArrayData data[25];
    char stringdata0[366];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver_t qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver = {
    {
QT_MOC_LITERAL(0, 0, 41), // "dfmplugin_titlebar::TitleBarE..."
QT_MOC_LITERAL(1, 42, 14), // "handleTabAdded"
QT_MOC_LITERAL(2, 57, 0), // ""
QT_MOC_LITERAL(3, 58, 8), // "windowId"
QT_MOC_LITERAL(4, 67, 16), // "handleTabChanged"
QT_MOC_LITERAL(5, 84, 5), // "index"
QT_MOC_LITERAL(6, 90, 14), // "handleTabMoved"
QT_MOC_LITERAL(7, 105, 4), // "from"
QT_MOC_LITERAL(8, 110, 2), // "to"
QT_MOC_LITERAL(9, 113, 15), // "handleTabRemovd"
QT_MOC_LITERAL(10, 129, 20), // "handleCustomRegister"
QT_MOC_LITERAL(11, 150, 6), // "scheme"
QT_MOC_LITERAL(12, 157, 10), // "properties"
QT_MOC_LITERAL(13, 168, 18), // "handleStartSpinner"
QT_MOC_LITERAL(14, 187, 17), // "handleStopSpinner"
QT_MOC_LITERAL(15, 205, 22), // "handleShowFilterButton"
QT_MOC_LITERAL(16, 228, 7), // "visible"
QT_MOC_LITERAL(17, 236, 21), // "handleViewModeChanged"
QT_MOC_LITERAL(18, 258, 4), // "mode"
QT_MOC_LITERAL(19, 263, 30), // "handleSetNewWindowAndTabEnable"
QT_MOC_LITERAL(20, 294, 6), // "enable"
QT_MOC_LITERAL(21, 301, 19), // "handleWindowForward"
QT_MOC_LITERAL(22, 321, 20), // "handleWindowBackward"
QT_MOC_LITERAL(23, 342, 19), // "handleRemoveHistory"
QT_MOC_LITERAL(24, 362, 3) // "url"

    },
    "dfmplugin_titlebar::TitleBarEventReceiver\0"
    "handleTabAdded\0\0windowId\0handleTabChanged\0"
    "index\0handleTabMoved\0from\0to\0"
    "handleTabRemovd\0handleCustomRegister\0"
    "scheme\0properties\0handleStartSpinner\0"
    "handleStopSpinner\0handleShowFilterButton\0"
    "visible\0handleViewModeChanged\0mode\0"
    "handleSetNewWindowAndTabEnable\0enable\0"
    "handleWindowForward\0handleWindowBackward\0"
    "handleRemoveHistory\0url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_titlebar__TitleBarEventReceiver[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x0a /* Public */,
       4,    2,   82,    2, 0x0a /* Public */,
       6,    3,   87,    2, 0x0a /* Public */,
       9,    2,   94,    2, 0x0a /* Public */,
      10,    2,   99,    2, 0x0a /* Public */,
      13,    1,  104,    2, 0x0a /* Public */,
      14,    1,  107,    2, 0x0a /* Public */,
      15,    2,  110,    2, 0x0a /* Public */,
      17,    2,  115,    2, 0x0a /* Public */,
      19,    1,  120,    2, 0x0a /* Public */,
      21,    1,  123,    2, 0x0a /* Public */,
      22,    1,  126,    2, 0x0a /* Public */,
      23,    2,  129,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::Int,    3,    5,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::Int, QMetaType::Int,    3,    7,    8,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::Int,    3,    5,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariantMap,   11,   12,
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::Bool,    3,   16,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::Int,    3,   18,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QUrl,    3,   24,

       0        // eod
};

void dfmplugin_titlebar::TitleBarEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TitleBarEventReceiver *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->handleTabAdded((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 1: _t->handleTabChanged((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->handleTabMoved((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->handleTabRemovd((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: { bool _r = _t->handleCustomRegister((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->handleStartSpinner((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 6: _t->handleStopSpinner((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 7: _t->handleShowFilterButton((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->handleViewModeChanged((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: _t->handleSetNewWindowAndTabEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->handleWindowForward((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 11: _t->handleWindowBackward((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 12: _t->handleRemoveHistory((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_titlebar::TitleBarEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver.data,
    qt_meta_data_dfmplugin_titlebar__TitleBarEventReceiver,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_titlebar::TitleBarEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_titlebar::TitleBarEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_titlebar__TitleBarEventReceiver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_titlebar::TitleBarEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
