/****************************************************************************
** Meta object code from reading C++ file 'usersharehelper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-dirshare/utils/usersharehelper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'usersharehelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper_t {
    QByteArrayData data[17];
    char stringdata0[214];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper_t qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper = {
    {
QT_MOC_LITERAL(0, 0, 35), // "dfmplugin_dirshare::UserShare..."
QT_MOC_LITERAL(1, 36, 17), // "shareCountChanged"
QT_MOC_LITERAL(2, 54, 0), // ""
QT_MOC_LITERAL(3, 55, 5), // "count"
QT_MOC_LITERAL(4, 61, 10), // "shareAdded"
QT_MOC_LITERAL(5, 72, 4), // "path"
QT_MOC_LITERAL(6, 77, 12), // "shareRemoved"
QT_MOC_LITERAL(7, 90, 17), // "shareRemoveFailed"
QT_MOC_LITERAL(8, 108, 16), // "sambaPasswordSet"
QT_MOC_LITERAL(9, 125, 7), // "success"
QT_MOC_LITERAL(10, 133, 14), // "readShareInfos"
QT_MOC_LITERAL(11, 148, 10), // "sendSignal"
QT_MOC_LITERAL(12, 159, 14), // "onShareChanged"
QT_MOC_LITERAL(13, 174, 18), // "onShareFileDeleted"
QT_MOC_LITERAL(14, 193, 12), // "onShareMoved"
QT_MOC_LITERAL(15, 206, 4), // "from"
QT_MOC_LITERAL(16, 211, 2) // "to"

    },
    "dfmplugin_dirshare::UserShareHelper\0"
    "shareCountChanged\0\0count\0shareAdded\0"
    "path\0shareRemoved\0shareRemoveFailed\0"
    "sambaPasswordSet\0success\0readShareInfos\0"
    "sendSignal\0onShareChanged\0onShareFileDeleted\0"
    "onShareMoved\0from\0to"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_dirshare__UserShareHelper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,
       6,    1,   70,    2, 0x06 /* Public */,
       7,    1,   73,    2, 0x06 /* Public */,
       8,    1,   76,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   79,    2, 0x09 /* Protected */,
      10,    0,   82,    2, 0x29 /* Protected | MethodCloned */,
      12,    1,   83,    2, 0x09 /* Protected */,
      13,    1,   86,    2, 0x09 /* Protected */,
      14,    2,   89,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Bool,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   15,   16,

       0        // eod
};

void dfmplugin_dirshare::UserShareHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<UserShareHelper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->shareCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->shareAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->shareRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->shareRemoveFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->sambaPasswordSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->readShareInfos((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->readShareInfos(); break;
        case 7: _t->onShareChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->onShareFileDeleted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->onShareMoved((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (UserShareHelper::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UserShareHelper::shareCountChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (UserShareHelper::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UserShareHelper::shareAdded)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (UserShareHelper::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UserShareHelper::shareRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (UserShareHelper::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UserShareHelper::shareRemoveFailed)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (UserShareHelper::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UserShareHelper::sambaPasswordSet)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_dirshare::UserShareHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper.data,
    qt_meta_data_dfmplugin_dirshare__UserShareHelper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_dirshare::UserShareHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_dirshare::UserShareHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_dirshare__UserShareHelper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_dirshare::UserShareHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_dirshare::UserShareHelper::shareCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_dirshare::UserShareHelper::shareAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dfmplugin_dirshare::UserShareHelper::shareRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dfmplugin_dirshare::UserShareHelper::shareRemoveFailed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void dfmplugin_dirshare::UserShareHelper::sambaPasswordSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
