/****************************************************************************
** Meta object code from reading C++ file 'canvasgridbroker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/desktop/core/ddplugin-canvas/broker/canvasgridbroker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasgridbroker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker_t {
    QByteArrayData data[11];
    char stringdata0[99];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker_t qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker = {
    {
QT_MOC_LITERAL(0, 0, 33), // "ddplugin_canvas::CanvasGridBr..."
QT_MOC_LITERAL(1, 34, 5), // "items"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 5), // "index"
QT_MOC_LITERAL(4, 47, 4), // "item"
QT_MOC_LITERAL(5, 52, 7), // "gridPos"
QT_MOC_LITERAL(6, 60, 5), // "point"
QT_MOC_LITERAL(7, 66, 7), // "QPoint*"
QT_MOC_LITERAL(8, 74, 3), // "pos"
QT_MOC_LITERAL(9, 78, 14), // "tryAppendAfter"
QT_MOC_LITERAL(10, 93, 5) // "begin"

    },
    "ddplugin_canvas::CanvasGridBroker\0"
    "items\0\0index\0item\0gridPos\0point\0QPoint*\0"
    "pos\0tryAppendAfter\0begin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ddplugin_canvas__CanvasGridBroker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       4,    2,   37,    2, 0x0a /* Public */,
       6,    2,   42,    2, 0x0a /* Public */,
       9,    3,   47,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::QStringList, QMetaType::Int,    3,
    QMetaType::QString, QMetaType::Int, QMetaType::QPoint,    3,    5,
    QMetaType::Int, QMetaType::QString, 0x80000000 | 7,    4,    8,
    QMetaType::Void, QMetaType::QStringList, QMetaType::Int, QMetaType::QPoint,    1,    3,   10,

       0        // eod
};

void ddplugin_canvas::CanvasGridBroker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CanvasGridBroker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QStringList _r = _t->items((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->item((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QPoint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->point((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QPoint*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->tryAppendAfter((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QPoint(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ddplugin_canvas::CanvasGridBroker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker.data,
    qt_meta_data_ddplugin_canvas__CanvasGridBroker,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ddplugin_canvas::CanvasGridBroker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::CanvasGridBroker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ddplugin_canvas__CanvasGridBroker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_canvas::CanvasGridBroker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
