/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp org.deepin.dde.Appearance1.xml -c Appearance_Interface -p appearance_interface
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "appearance_interface.h"

/*
 * Implementation of interface class Appearance_Interface
 */

DDP_BACKGROUND_USE_NAMESPACE

Appearance_Interface::Appearance_Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

Appearance_Interface::~Appearance_Interface()
{
}

