/****************************************************************************
** Meta object code from reading C++ file 'trashcoreeventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/common/core/dfmplugin-trashcore/events/trashcoreeventreceiver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trashcoreeventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver_t {
    QByteArrayData data[11];
    char stringdata0[172];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver_t qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver = {
    {
QT_MOC_LITERAL(0, 0, 43), // "dfmplugin_trashcore::TrashCor..."
QT_MOC_LITERAL(1, 44, 16), // "handleEmptyTrash"
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 8), // "windowId"
QT_MOC_LITERAL(4, 71, 16), // "cutFileFromTrash"
QT_MOC_LITERAL(5, 88, 11), // "QList<QUrl>"
QT_MOC_LITERAL(6, 100, 7), // "sources"
QT_MOC_LITERAL(7, 108, 6), // "target"
QT_MOC_LITERAL(8, 115, 37), // "dfmbase::AbstractJobHandler::..."
QT_MOC_LITERAL(9, 153, 5), // "flags"
QT_MOC_LITERAL(10, 159, 12) // "copyFromFile"

    },
    "dfmplugin_trashcore::TrashCoreEventReceiver\0"
    "handleEmptyTrash\0\0windowId\0cutFileFromTrash\0"
    "QList<QUrl>\0sources\0target\0"
    "dfmbase::AbstractJobHandler::JobFlags\0"
    "flags\0copyFromFile"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_trashcore__TrashCoreEventReceiver[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       1,    0,   37,    2, 0x2a /* Public | MethodCloned */,
       4,    4,   38,    2, 0x0a /* Public */,
      10,    4,   47,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::ULongLong,    3,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::ULongLong, 0x80000000 | 5, QMetaType::QUrl, 0x80000000 | 8,    3,    6,    7,    9,
    QMetaType::Bool, QMetaType::ULongLong, 0x80000000 | 5, QMetaType::QUrl, 0x80000000 | 8,    3,    6,    7,    9,

       0        // eod
};

void dfmplugin_trashcore::TrashCoreEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TrashCoreEventReceiver *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->handleEmptyTrash((*reinterpret_cast< const quint64(*)>(_a[1]))); break;
        case 1: _t->handleEmptyTrash(); break;
        case 2: { bool _r = _t->cutFileFromTrash((*reinterpret_cast< const quint64(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])),(*reinterpret_cast< const dfmbase::AbstractJobHandler::JobFlags(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->copyFromFile((*reinterpret_cast< const quint64(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2])),(*reinterpret_cast< const QUrl(*)>(_a[3])),(*reinterpret_cast< const dfmbase::AbstractJobHandler::JobFlags(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< dfmbase::AbstractJobHandler::JobFlags >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            case 3:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< dfmbase::AbstractJobHandler::JobFlags >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_trashcore::TrashCoreEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver.data,
    qt_meta_data_dfmplugin_trashcore__TrashCoreEventReceiver,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_trashcore::TrashCoreEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_trashcore::TrashCoreEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_trashcore__TrashCoreEventReceiver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_trashcore::TrashCoreEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
